@@ -1,5 +1,5 @@
 /*
- * smartcalc v1.0.7
+ * smartcalc v1.0.8
  * Copyright (c) Erhan BARIS (Ruslan Ognyanov Asenov)
  * Licensed under the GNU General Public License v2.0.
  */
@@ -52,7 +52,7 @@ impl DataItem for DateTimeItem {
         }
 
         let date = self.0;
-        let duration = other.as_any().downcast_ref::<DurationItem>().unwrap().get_duration();
+        let duration = other.as_any().downcast_ref::<DurationItem>()?.get_duration();
         match operation_type {
             OperationType::Add => Some(Rc::new(DateTimeItem(date + duration, self.1.clone()))),
             OperationType::Sub => Some(Rc::new(DateTimeItem(date - duration, self.1.clone()))),
