@@ -1,5 +1,5 @@
 /*
- * smartcalc v1.0.7
+ * smartcalc v1.0.8
  * Copyright (c) Erhan BARIS (Ruslan Ognyanov Asenov)
  * Licensed under the GNU General Public License v2.0.
  */
@@ -7,12 +7,13 @@
 use core::borrow::Borrow;
 use core::ops::Deref;
 use alloc::collections::BTreeMap;
+use alloc::vec;
 use alloc::vec::Vec;
 use alloc::rc::Rc;
 use alloc::string::{String, ToString};
 use anyhow::anyhow;
-use crate::Session;
-use crate::tokinizer::{read_currency, RuleType};
+use crate::{Session, TimeOffset};
+use crate::tokinizer::{read_currency, RuleType, small_date};
 
 use crate::compiler::Interpreter;
 use crate::logger::{LOGGER, initialize_logger};
@@ -21,7 +22,7 @@ use crate::token::ui_token::UiToken;
 use crate::tokinizer::TokenInfo;
 use crate::tokinizer::Tokinizer;
 use crate::tools::parse_timezone;
-use crate::types::TokenType;
+use crate::types::{TokenType, ExpressionFunc};
 use crate::types::SmartCalcAstType;
 use crate::formatter::format_result;
 use crate::config::{SmartCalcConfig, DynamicType};
@@ -73,9 +74,22 @@ pub struct SmartCalc {
 impl Default for SmartCalc {
     fn default() -> Self {
         initialize_logger();
-        SmartCalc {
+        let mut smartcalc = SmartCalc {
             config: SmartCalcConfig::default()
-        }
+        };
+        smartcalc.set_date_rule("en", vec![
+            "{MONTH:month} {NUMBER:day}, {NUMBER:year}".to_string(),
+            "{MONTH:month} {NUMBER:day} {NUMBER:year}".to_string(),
+            "{NUMBER:day}/{NUMBER:month}/{NUMBER:year}".to_string(),
+            "{NUMBER:day} {MONTH:month} {NUMBER:year}".to_string(),
+            "{NUMBER:day} {MONTH:month}".to_string()
+        ]);
+        smartcalc.set_date_rule("tr", vec![
+            "{NUMBER:day}/{NUMBER:month}/{NUMBER:year}".to_string(),
+            "{NUMBER:day} {MONTH:month} {NUMBER:year}".to_string(),
+            "{NUMBER:day} {MONTH:month}".to_string()
+        ]);
+        smartcalc
     }
 }
 
@@ -116,6 +130,23 @@ impl SmartCalc {
         true
     }
     
+    pub fn set_money_configuration(&mut self, remove_fract_if_zero: bool, use_fract_rounding: bool) {
+        self.config.money_config.remove_fract_if_zero = remove_fract_if_zero;
+        self.config.money_config.use_fract_rounding = use_fract_rounding;
+    }
+    
+    pub fn set_number_configuration(&mut self, decimal_digits: u8, remove_fract_if_zero: bool, use_fract_rounding: bool) {
+        self.config.number_config.decimal_digits = decimal_digits;
+        self.config.number_config.remove_fract_if_zero = remove_fract_if_zero;
+        self.config.number_config.use_fract_rounding = use_fract_rounding;
+    }
+    
+    pub fn set_percentage_configuration(&mut self, decimal_digits: u8, remove_fract_if_zero: bool, use_fract_rounding: bool) {
+        self.config.percentage_config.decimal_digits = decimal_digits;
+        self.config.percentage_config.remove_fract_if_zero = remove_fract_if_zero;
+        self.config.percentage_config.use_fract_rounding = use_fract_rounding;
+    }
+
     pub fn set_decimal_seperator(&mut self, decimal_seperator: String) {
         self.config.decimal_seperator = decimal_seperator;
     }
@@ -124,10 +155,45 @@ impl SmartCalc {
         self.config.thousand_separator = thousand_separator;
     }
     
+    pub fn set_date_rule(&mut self, language: &str, rules: Vec<String>) {                
+        let mut function_items = Vec::new();
+        for rule_item in rules {
+            let mut session = Session::new();
+            session.set_language(language.to_string());
+            session.set_text(rule_item.to_string());
+            function_items.push(Tokinizer::token_infos(&self.config, &session));
+        }
+        
+        let current_rules = match self.config.rule.get_mut(language) {
+            Some(current_rules) => current_rules,
+            None => return
+        };
+
+        /* Remove small_date rule */
+        current_rules.retain(|rule| {
+            let is_small_date = if let RuleType::Internal { function_name, .. } = rule {
+                function_name == "small_date"
+            } else {
+                false
+            };
+            
+            !is_small_date
+        });
+        
+        current_rules.push(RuleType::Internal {
+            function_name: "small_date".to_string(),
+            function: small_date as ExpressionFunc,
+            tokens_list: function_items
+        });
+    }
+    
     pub fn set_timezone(&mut self, timezone: String) -> Result<(), String> {
         let timezone = match self.config.token_parse_regex.get("timezone") {
             Some(regexes) => {
-                let capture = regexes[0].captures(&timezone).unwrap();
+                let capture = match regexes[0].captures(&timezone) {
+                    Some(capture) => capture,
+                    None => return Err("Timezone information not found".to_string())
+                };
                 match capture.name("timezone") {
                     Some(_) => parse_timezone(&self.config, &capture),
                     None => None
@@ -145,6 +211,10 @@ impl SmartCalc {
             None => Err("Timezone information not found".to_string())
         }
     }
+
+    pub fn get_time_offset(&self) -> TimeOffset {
+        self.config.get_time_offset()
+    }
     
     pub fn load_from_json(json_data: &str) -> Self {
         SmartCalc {
@@ -161,7 +231,27 @@ impl SmartCalc {
              _ => false
         }
     }
-
+    
+    pub fn delete_rule(&mut self, language: String, rule_name: String) -> bool {
+        match self.config.rule.get_mut(&language) {
+            Some(language_collection) => {
+                let position = language_collection.iter().position(|item| match item {
+                    RuleType::API { tokens_list: _, rule: rule_item } => rule_name == rule_item.name(),
+                    _ => false
+                });
+                
+                match position {
+                    Some(location) => {
+                        language_collection.remove(location);
+                        true
+                    }
+                    _ => false
+                }
+            },
+            None => false
+        }
+    }
+    
     pub fn add_rule(&mut self, language: String, rules: Vec<String>, rule: Rc<dyn RuleTrait>) -> bool {
         let mut rule_tokens = Vec::new();
         
@@ -405,6 +495,25 @@ mod test {
         Ok(())
     }
     
+    #[test]
+    fn delete_rule_2() ->  Result<(), ()> {
+        let mut calculater = SmartCalc::default();
+        let test1 = Rc::new(Test1::default());
+        assert!(calculater.add_rule("en".to_string(), vec!["erhan {TEXT:surname:baris}".to_string(), "{TEXT:surname:baris} erhan".to_string()], test1.clone()));
+        assert!(calculater.delete_rule("en".to_string(), test1.name().clone()));
+
+        Ok(())
+    }
+    
+    #[test]
+    fn delete_rule_3() ->  Result<(), ()> {
+        let mut calculater = SmartCalc::default();
+        let test1 = Rc::new(Test1::default());
+        assert!(!calculater.delete_rule("en".to_string(), test1.name().clone()));
+
+        Ok(())
+    }
+    
     #[test]
     fn dynamic_type_1() ->  Result<(), ()> {
         let mut calculater = SmartCalc::default();
@@ -524,7 +633,7 @@ mod test {
                 _ => return None
             };
             
-            return Some(TokenType::Money(price, smartcalc.get_currency("usd".to_string()).unwrap()));
+            return Some(TokenType::Money(price, smartcalc.get_currency("usd".to_string())?));
         }
     }
     
